@@ -19,14 +19,16 @@ using System;
 
 namespace Docky.Services
 {
-	
 	public enum NetworkState {
 		Unknown = 0,
-		Asleep,
-		Connecting,
-		Connected,
-		Disconnected
-	}	
+		Asleep = 10,
+		Disconnected = 20,
+		Disconnecting = 30,
+		Connecting = 40,
+		ConnectedLocal = 50,
+		ConnectedSite = 60,
+		ConnectedGlobal = 70
+	}
 
 	public class ConnectionStatusChangeEventArgs : EventArgs
 	{
